Documentation
¶
Index ¶
Constants ¶
const ( // FrameCols is the X resolution of the Lepton 3 camera. FrameCols = 160 // FrameRows is the Y resolution of the Lepton 3 camera. FrameRows = 120 )
const ( FFCNever = "never" FFCImminent = "imminent" FFCRunning = "running" FFCComplete = "complete" )
These are the valid values for the Telemetry.FFCState field.
const FramesHz = 9
FramesHz define the approximate number of frames per second emitted by the Lepton 3 camera.
Variables ¶
var Big16 big16
Big16 translates big endian 16bits words but everything larger is in little endian.
It implements binary.ByteOrder.
Functions ¶
func ParseTelemetry ¶
ParseTelemetry converts a slice containing raw Lepton 3 telemetry data into a Telemetry struct.
Types ¶
type Lepton3 ¶
type Lepton3 struct {
// contains filtered or unexported fields
}
Lepton3 manages a connection to an FLIR Lepton 3 camera. It is not goroutine safe.
func (*Lepton3) Close ¶
func (d *Lepton3) Close()
Close stops streaming of packets from the camera and closes the SPI device connection. It must only be called if streaming was started with Open().
func (*Lepton3) NextFrame ¶
NextFrame returns the next frame from the camera into the RawFrame provided.
The output RawFrame is provided (rather than being created by NextFrame) to minimise memory allocations.
NextFrame should only be called after a successful call to Open(). Although there is some internal buffering of camera packets, NextFrame must be called frequently enough to ensure frames are not lost.
func (*Lepton3) Open ¶
Open initialises the SPI connection and starts streaming packets from the camera.
func (*Lepton3) SetLogFunc ¶
func (*Lepton3) SetRadiometry ¶
SetRadiometry enables or disables radiometry mode. If enabled, the camera will attempt to automatically compensate for ambient temperature changes.